@@ -28,6 +28,9 @@ EX_TEST_COMMAND_NAME = 'ep2_ex_test'
 UTIL_COMMAND_NAME = 'ep2_util'
 EVAL_COMMAND_NAME = 'ep2_eval'
 
+KEY_UE_NO = 'ue'
+KEY_UE_TAG = 'tag'
+
 
 def relative_path(basedir, filename):
     """Creates a path relative to base"""
@@ -358,7 +361,23 @@ class Ep2:
     def create_project_issue(self, project:str, title:str, descrition:str):
         proj = self.gitlab.projects.get(project, lazy=True)  # fetch project (gitlab) and add issue
 
-        proj.issues.create({'title': title, 'description': descrition}, sudo=self.sudo)
+        proj.issues.create({'title': title, 'description': descrition}, sudo=self.sudo,
+                           headers={'content-type': 'application/json; charset=UTF-8'})
+
+    def get_ue_tag(self, ue: int):
+        csv_file = os.path.join(self.tutor_repo(), "tags.csv")
+
+        with open(csv_file, 'r') as infile:
+            reader = csv.DictReader(infile, [KEY_UE_NO, KEY_UE_TAG], KEY_INVALID, strict=True)
+
+            headers = next(reader, None)
+            if not validate_headers(headers):
+                click.secho('Malformed file: %s. Invalid headers!' % csv_file)
+                exit(1)
+
+            for row in reader:
+                if int(row[KEY_UE_NO]) == ue:
+                    return row[KEY_UE_TAG]
 
     def print_sudo_header(self):
         user = self.gitlab.users.list(username=self.sudo)[0]
