@@ -77,7 +77,12 @@ def util_init(semester, git_home, gitlab_url, gitlab_repo_prefix, gitlab_access_
             config.set('Gitlab', 'RepoPrefix', 'ep2/2020s')
         else:  # Should not be possible
             click.secho('unimplemented semester: ' + semester, fg='red')
+            exit(1)
     else:  # Use info provided by options
+        if (gitlab_url is None or gitlab_url == '') or (gitlab_repo_prefix is None or gitlab_repo_prefix == ''):
+            click.secho('Please provide --gitlab-url and --gitlab-repo-prefix or --semester!')
+            exit(1)
+
         config.set('Gitlab', 'URL', gitlab_url)
         config.set('Gitlab', 'RepoPrefix', gitlab_repo_prefix)
 
